.. currentmodule:: obspy.core
.. automodule:: obspy.core

    .. comment to end block


    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       ~stream.read
       ~stream.Stream
       ~trace.Trace
       ~trace.Stats
       ~utcdatetime.UTCDateTime
       ~event.read_events
       ~event.Catalog
       ~event.Event
       ~inventory.inventory.read_inventory
       ~inventory.inventory.Inventory

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       trace
       stream
       utcdatetime
       event
       inventory
       util
       preview

    .. comment to end block
